## START: Set by rpmautospec
## (rpmautospec version 0.6.0)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 2;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

%global srcname pyshtools

%if 0%{?fedora} || 0%{?rhel} >= 9
%global blaslib flexiblas
%else
%global blaslib openblas
%endif

Name:           python-%{srcname}
Version:        4.12.2
Release:        %autorelease
Summary:        Tools for working with spherical harmonics

License:        BSD-3-Clause
URL:            https://shtools.github.io/SHTOOLS/
Source0:        %pypi_source %{srcname}
# We don't need oldest-supported-numpy as NumPy is always built for "this" Python.
Patch:          0001-Use-normal-numpy-as-build-dependency.patch
# https://github.com/SHTOOLS/SHTOOLS/pull/472
Patch:          0002-Stop-using-deprecated-Matplotlib-API.patch

# https://fedoraproject.org/wiki/Changes/EncourageI686LeafRemoval
ExcludeArch: %{ix86}

BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gcc-gfortran
BuildRequires:  fftw3-devel
BuildRequires:  %{blaslib}-devel
BuildRequires:  make
BuildRequires:  python3-devel
BuildRequires:  python3-f2py

# Runtime dependencies (we can't use automatic build requires due to build issues).
BuildRequires:  python3dist(scipy) >= 0.14
BuildRequires:  python3dist(matplotlib) >= 3.3
BuildRequires:  python3dist(astropy) >= 4
BuildRequires:  python3dist(xarray)
BuildRequires:  python3dist(requests)
BuildRequires:  python3dist(pooch) >= 1.1
BuildRequires:  python3dist(tqdm)

# Optional dependencies.
BuildRequires:  python3dist(cartopy) >= 0.18
BuildRequires:  python3dist(ducc0) >= 0.15

%description
pysthools is a Python library that can be used to perform spherical
harmonic transforms and reconstructions, multitaper spectral analyses on
the sphere, expansions of functions into Slepian bases, and standard
operations on global gravitational and magnetic field data.


%package -n     python3-%{srcname}
Summary:        %{summary}
Recommends:     python3-%{srcname}+cartopy
Recommends:     python3-%{srcname}+ducc

%description -n python3-%{srcname}
pysthools is a Python library that can be used to perform spherical
harmonic transforms and reconstructions, multitaper spectral analyses on
the sphere, expansions of functions into Slepian bases, and standard
operations on global gravitational and magnetic field data.


%pyproject_extras_subpkg -n python3-%{srcname} cartopy ducc


%prep
%autosetup -n %{srcname}-%{version} -p1

%generate_buildrequires
%pyproject_buildrequires -R

%build
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%pyproject_wheel -Csetup-args=-Dblas=%{blaslib} -Csetup-args=-Dlapack=%{blaslib}

%install
%pyproject_install
%pyproject_save_files %{srcname}

%check
export MPLBACKEND=Agg %py3_test_envvars
make -C examples/python -f Makefile no-timing PYTHON=%{python3}

%files -n python3-%{srcname} -f %{pyproject_files}
%doc README.md

%changelog
## START: Generated by rpmautospec
* Wed May 22 2024 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 4.12.2-2
- Fix build with Matplotlib 3.9

* Fri Apr 26 2024 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 4.12.2-1
- Update to latest version (#2270123)

* Tue Feb 27 2024 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 4.11.10-1
- Update to latest version (#2258807)

* Fri Jan 26 2024 Fedora Release Engineering <releng@fedoraproject.org> - 4.10.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 4.10.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Tue Aug 29 2023 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 4.10.4-1
- Update to latest version (#2235318)

* Wed Jul 19 2023 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 4.10.3-2
- Rebuild for Python 3.12b4

* Tue May 23 2023 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 4.10.3-1
- Update to latest version (#2208002)

* Sat May 06 2023 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 4.10.2-1
- Update to latest version (#2193143)

* Sun Apr 09 2023 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 4.10.1-8
- Switch to SPDX license

* Wed Apr 05 2023 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 4.10.1-7
- Remove workaround for missing python-ducc0

* Wed Apr 05 2023 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 4.10.1-6
- Fix build with latest setuptools (#2183395)

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 4.10.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Mon Dec 19 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 4.10.1-4
- Work around python-ducc0 ExcludeArch

* Mon Dec 19 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 4.10.1-3
- Fix weak dependencies on extras subpackages

* Mon Dec 19 2022 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 4.10.1-2
- Drop support for i686

* Mon Oct 17 2022 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 4.10.1-1
- Update to latest version (#2125643)

* Mon Aug 08 2022 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 4.10-1
- Update to latest version (#1878694)

* Mon Aug 08 2022 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 4.6.2-13
- Switch to latest Python macros

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 4.6.2-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Fri Jul 15 2022 Python Maint <python-maint@redhat.com> - 4.6.2-9
- Rebuilt for Python 3.11

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 4.6.2-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 4.6.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 4.6.2-6
- Rebuilt for Python 3.10

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 4.6.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Sun Aug 16 2020 Iñaki Úcar <iucar@fedoraproject.org> - 4.6.2-4
- https://fedoraproject.org/wiki/Changes/FlexiBLAS_as_BLAS/LAPACK_manager

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 4.6.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 4.6.2-2
- Rebuilt for Python 3.9

* Sat May 16 2020 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 4.6.2-1
- Update to latest version
- Cleanup old workarounds

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 4.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Mon Sep 23 2019 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 4.5-1
- Update to latest version

* Mon Aug 19 2019 Miro Hrončok <mhroncok@redhat.com> - 4.4.1-4
- Rebuilt for Python 3.8

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 4.4.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 4.4.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Jan 12 2019 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 4.4.1-1
- Update to latest version

* Sat Aug 18 2018 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 4.3-1
- Initial package.

## END: Generated by rpmautospec
